@@ -1,30 +1,34 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 
 """
 Main file containing the mito widget.
 """
 import json
+import time
 from typing import Any, Dict, List, Union
-import pandas as pd
-import random
-from ipywidgets import DOMWidget
-import traitlets as t
 
-from mitosheet.mito_analytics import log, log_event_processed, log_recent_error, telemetry_turned_on
-from mitosheet.step_performers import STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID
-from mitosheet.user.schemas import UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_TOURS, UJ_USER_EMAIL
-from mitosheet.user.db import get_user_field
-from mitosheet.user.utils import is_pro
-from mitosheet.api import API
+import pandas as pd
+from mitosheet.user.location import is_in_google_colab, is_in_vs_code
+import traitlets as t
+from ipywidgets import DOMWidget
+
 from mitosheet._frontend import module_name, module_version
+from mitosheet.api import API
+from mitosheet.data_in_mito import DataTypeInMito
 from mitosheet.errors import MitoError, get_recent_traceback
+from mitosheet.mito_analytics import (log, log_event_processed,
+                                      log_recent_error, telemetry_turned_on)
 from mitosheet.saved_analyses import write_analysis
 from mitosheet.steps_manager import StepsManager
 from mitosheet.user import is_local_deployment, should_upgrade_mitosheet
-from mitosheet.data_in_mito import DataTypeInMito
+from mitosheet.user.db import get_user_field
+from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES,
+                                    UJ_RECEIVED_TOURS, UJ_USER_EMAIL)
+from mitosheet.user.utils import is_excel_import_enabled, is_pro
 
 
 class MitoWidget(DOMWidget):
@@ -92,6 +96,7 @@ class MitoWidget(DOMWidget):
             'isPro': is_pro(),
             'telemetryEnabled': telemetry_turned_on(),
             # Static over a single analysis
+            'excelImportEnabled': is_excel_import_enabled(),
             'isLocalDeployment': self.is_local_deployment,
             'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
             'numUsages': self.num_usages,
@@ -161,7 +166,7 @@ class MitoWidget(DOMWidget):
 
     def receive_message(self, widget: Any, content: Dict[str, Any], buffers: Any=None) -> bool:
         """
-        Handles all incoming messages from the JS widget. There are two main
+        Handles all incoming messages from the JS widget. There are three main
         types of events:
 
         1. edit_event: any event that updates the state of the sheet and the
@@ -171,8 +176,13 @@ class MitoWidget(DOMWidget):
         other types of new data coming from the frontend (e.g. the df names 
         or some existing steps).
 
-        3. A log_event is just an event that should get logged on the backend.
+        3. api_call: an event that is used to retrieve information from the backend without
+        updating the backend state.
+
+        4. A log_event is just an event that should get logged on the backend.
         """
+
+        start_time = time.perf_counter()
         event = content
 
         try:
@@ -187,7 +197,7 @@ class MitoWidget(DOMWidget):
             # NOTE: we don't need to case on log_event above because it always gets
             # passed to this function, and thus is logged. However, we do not log
             # api calls, as they are just noise.
-            log_event_processed(event, self.steps_manager)
+            log_event_processed(event, self.steps_manager, start_time=start_time)
 
             return True
         except MitoError as e:
@@ -195,7 +205,7 @@ class MitoWidget(DOMWidget):
             print(e)
             
             # Log processing this event failed
-            log_event_processed(event, self.steps_manager, failed=True, mito_error=e)
+            log_event_processed(event, self.steps_manager, failed=True, mito_error=e, start_time=start_time)
 
             # If the error says to ignore the error modal, then we
             # send some data with the response so that the frontend
@@ -222,7 +232,7 @@ class MitoWidget(DOMWidget):
         except:
             print(get_recent_traceback())
             # We log that processing failed, but have no edit error
-            log_event_processed(event, self.steps_manager, failed=True)
+            log_event_processed(event, self.steps_manager, failed=True, start_time=start_time)
             # Report it to the user, and then return
             self.send({
                 'event': 'edit_error',
@@ -262,12 +272,19 @@ def sheet(
     python -m pip install mitoinstaller
     python -m mitoinstaller install
 
-    Run this command in the terminal where you installed Mito. It should take 5-10 minutes to complete.
+    Run this command in the terminal where you installed Mito. It should take 1-2 minutes to complete.
 
     Then, restart your JupyterLab instance, and refresh your browser. Mito should now render.
 
     NOTE: if you have any issues with installation, please email jake@sagacollab.com
     """
+    # We throw a custom error message if we're sure the user is in
+    # vs code or google collab (these conditions are more secure than
+    # the conditons for checking if we're in JLab or JNotebook).
+    if is_in_vs_code() or is_in_google_colab():
+        log_recent_error('mitosheet_sheet_call_location_failed')
+        raise Exception("The mitosheet currently only works in JupyterLab.\n\nTo see instructions on getting Mitosheet running in JupyterLab, find install instructions here: https://docs.trymito.io/getting-started/installing-mito")
+
     try:
         # We pass in the dataframes directly to the widget
         widget = MitoWidget(*args) 
