@@ -1,4 +1,11 @@
+#!/usr/bin/env python
+# coding: utf-8
+
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
+
 from typing import Any, Dict, List, Optional, Set, Type
+from mitosheet.evaluation_graph_utils import create_column_evaluation_graph
 
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.column_steps.set_column_formula import SetColumnFormulaStepPerformer
@@ -73,25 +80,16 @@ class Step:
     def column_ids(self):
         return self.post_state.column_ids
     
-    @property
-    def column_metatype(self):
-        return self.post_state.column_metatype
-
-    @property
-    def column_type(self):
-        return self.post_state.column_type
-    
     @property
     def column_spreadsheet_code(self):
         return self.post_state.column_spreadsheet_code
 
     @property
     def column_evaluation_graph(self):
-        return self.post_state.column_evaluation_graph
-
-    @property
-    def column_python_code(self):
-        return self.post_state.column_python_code
+        return [
+            create_column_evaluation_graph(self.post_state, sheet_index)
+            for sheet_index in range(len(self.dfs))
+        ]
     
     @property
     def column_filters(self):
@@ -101,6 +99,14 @@ class Step:
     def column_format_types(self):
         return self.post_state.column_format_types
 
+    @property
+    def graph_data(self) -> Dict[str, Dict[str, Any]]:
+        """
+        graph_data contains all of the parameters used to construct the graph,
+        the actual graph html & javascript, and the generated code for all of the existing graphs in Mito.
+        """
+        return self.final_defined_state.graph_data
+
     @property
     def step_performer(self) -> Type[StepPerformer]:
         """
@@ -117,7 +123,7 @@ class Step:
     def final_defined_state(self) -> State:
         """
         Returns the final defined state in this step, as the prev and post
-        state are optional, but we also need a step to have a defined step
+        state are optional, but we also need a step to have a defined state
         """
         return self.post_state if self.post_state is not None else \
             (self.prev_state if self.prev_state is not None else State([]))
