@@ -1,14 +1,12 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 Contains tests for edit events.
 """
 import random
-from typing import List
 
 from mitosheet.step_performers import (
     STEP_PERFORMERS,
@@ -31,7 +29,8 @@ from mitosheet.step_performers import (
     DataframeRenameStepPerformer,
     BulkOldRenameStepPerformer, 
     ExcelImportStepPerformer,
-    DropDuplicatesStepPerformer
+    DropDuplicatesStepPerformer,
+    GraphStepPerformer
 )
 
 def check_step(
@@ -87,7 +86,7 @@ def test_params_static():
 
     check_step(
         FilterStepPerformer,
-        3,
+        4,
         'filter_column'
     )
     
@@ -183,7 +182,13 @@ def test_params_static():
         'drop_duplicates'
     )
 
-    assert len(STEP_PERFORMERS) == 19
+    check_step(
+        GraphStepPerformer,
+        1,
+        'graph'
+    )
+
+    assert len(STEP_PERFORMERS) == 20
 
 
 def get_fake_param(param_name):
