@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 This file contains helpful functions and classes for testing operations.
 """
@@ -11,11 +10,13 @@ This file contains helpful functions and classes for testing operations.
 import json
 from functools import wraps
 from typing import Any, Dict, List, Union
+from numpy import number
 
 import pandas as pd
 from mitosheet.mito_widget import MitoWidget, sheet
+from mitosheet.parser import parse_formula
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.types import ColumnHeader, ColumnID, MultiLevelColumnHeader, PrimativeColumnHeader
+from mitosheet.types import ColumnHeader, ColumnID, MultiLevelColumnHeader
 from mitosheet.utils import dfs_to_array_for_json, get_new_id
 
 
@@ -81,7 +82,6 @@ def check_dataframes_equal(test_wrapper):
     )
 
     import mitosheet
-    
     exec(code, 
         {
             'check_final_dataframe': check_final_dataframe,
@@ -103,7 +103,6 @@ def check_dataframes_equal(test_wrapper):
         test_wrapper.mito_widget.steps_manager.curr_step.df_sources,
         test_wrapper.mito_widget.steps_manager.curr_step.column_spreadsheet_code,
         test_wrapper.mito_widget.steps_manager.curr_step.column_filters,
-        test_wrapper.mito_widget.steps_manager.curr_step.column_type,
         test_wrapper.mito_widget.steps_manager.curr_step.column_ids,
         test_wrapper.mito_widget.steps_manager.curr_step.column_format_types
     ))
@@ -287,7 +286,7 @@ class MitoWidgetTestWrapper:
             pivot_rows: List[ColumnHeader],
             pivot_columns: List[ColumnHeader],
             values: Dict[ColumnHeader, List[str]],
-            flatten_column_headers: bool=False,
+            flatten_column_headers: bool=True,
             destination_sheet_index: int=None,
             step_id: str=None
         ) -> bool:
@@ -329,7 +328,6 @@ class MitoWidgetTestWrapper:
             sheet_index: int, 
             column_header: ColumnHeader,
             operator: str,
-            type_: str,
             condition: str, 
             value: Any
         ) -> bool:
@@ -351,7 +349,6 @@ class MitoWidgetTestWrapper:
                     'column_id': column_id,
                     'operator': operator,
                     'filters': [{
-                        'type': type_,
                         'condition': condition,
                         'value': value
                     }]
@@ -730,6 +727,44 @@ class MitoWidgetTestWrapper:
         )
 
 
+    def generate_graph(
+        self, 
+        graph_type: str, 
+        sheet_index: number,
+        safety_filter_turned_on_by_user: bool,
+        xAxisColumnIDs: List[ColumnID],
+        yAxisColumnIDs: List[ColumnID],
+        height: str,
+        width: str,
+        step_id: str=None
+    ) -> bool:
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'graph_edit',
+                'step_id': get_new_id() if step_id is None else step_id,
+                'params': {
+                    'graph_preprocessing': {
+                    'safety_filter_turned_on_by_user': safety_filter_turned_on_by_user
+                    },
+                    'graph_creation': {
+                        'graph_type': graph_type,
+                        'sheet_index': sheet_index,
+                        'x_axis_column_ids': xAxisColumnIDs,
+                        'y_axis_column_ids': yAxisColumnIDs,
+                    },
+                    'graph_styling': {},
+                    'graph_rendering': {
+                        'height': height,
+                        'width': width
+                    }
+                }
+            }
+        )
+
+
     def get_formula(self, sheet_index: int, column_header: ColumnHeader) -> str:
         """
         Gets the formula for a given column. Returns an empty
@@ -750,9 +785,19 @@ class MitoWidgetTestWrapper:
         column_id = self.mito_widget.steps_manager.curr_step.get_column_id_by_header(
             sheet_index, column_header
         )
-        if column_id not in self.mito_widget.steps_manager.curr_step.column_python_code[sheet_index]:
+        if column_id not in self.mito_widget.steps_manager.curr_step.column_spreadsheet_code[sheet_index]:
             return ''
-        return self.mito_widget.steps_manager.curr_step.column_python_code[sheet_index][column_id]
+
+        column_headers = self.curr_step.post_state.dfs[sheet_index].keys()
+
+        # We compile all of their formulas
+        python_code, _, _ = parse_formula(
+            self.curr_step.post_state.column_spreadsheet_code[sheet_index][column_id], 
+            column_header,
+            column_headers
+        )
+
+        return python_code
 
     def get_value(self, sheet_index: int, column_header: ColumnHeader, row: int) -> Any:
         """
@@ -774,6 +819,12 @@ class MitoWidgetTestWrapper:
             return self.mito_widget.steps_manager.dfs[sheet_index][column_header].tolist()
         return self.mito_widget.steps_manager.dfs[sheet_index][column_header]
 
+    def get_graph_data(self, graph_id: str) -> Dict[str, Dict[str, Any]]: 
+        """
+        Returns the graph_data object 
+        """
+        return self.mito_widget.steps_manager.curr_step.final_defined_state.graph_data[graph_id]
+
     
 
 def create_mito_wrapper(sheet_one_A_data: List[Any], sheet_two_A_data: List[Any]=None) -> MitoWidgetTestWrapper:
